==> Repetier-Server-Frontend-0.86.2.zip: Repetier-Server-Frontend/wwwsrc/modules/front2/app/register.browser.ts <==
/* (C) 2016 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {platformBrowserDynamic} from '@angular/platform-browser-dynamic';
import {Component, ViewContainerRef, ChangeDetectionStrategy} from '@angular/core';
import {Routes, RouterModule} from '@angular/router';
import {BrowserModule} from '@angular/platform-browser';
import {enableProdMode} from '@angular/core';
import {HttpModule} from '@angular/http';
import {
    RepetierServer, Language, WifiState, LicenseState, LicenseAction, ConnectionHandler,
    ServerAction, RepetierState, VisualAids, ServerEvent, ServerState
} from "@repetier/binding";
import {FrontUIModule, RSModal, RSUIVisualAids, RSLicenceKeyboard} from '@repetier/front-ui';
import {ISubscription} from "rxjs/Subscription";
import {NgModule}      from '@angular/core';
import {WLANComponent} from "./wlan.component";
import {select, NgRedux} from 'ng2-redux';
import {Observable} from 'rxjs/Observable';

@Component({
    selector: 'front-register',
    template: `
<rs-page>
<side>
    <rs-sideicon title="<?php _('Home') ?>" icon="rs rs-key" (rsclick)="page=0"></rs-sideicon>
</side>
<side>
    <rs-sideicon *ngIf="(wifi$ | async).manageable" icon="fa fa-wifi" title="WLAN" link="/wlan"></rs-sideicon>
</side>
<side>
    <rs-sideicon title="<?php _('Language') ?>" icon="fa fa-language" (rsclick)="page=1"></rs-sideicon>
</side>
<main>
<div *ngIf="page==0">
    <h1 class="margin-bottom"><i class="rs rs-key"></i> <?php _('License Activation') ?></h1>
    <div class="content-h1 margin" rs-drag>
        <div *ngIf="!online" class="alert warning">
            <i class="fa fa-warning"></i> <?php _('It seems you are not connected with the internet. Activation will work only with active internet connection!') ?>
        </div>
        <p> <?php _('The requested function requires a active licence.') ?></p>
        <div class="alert error" style="margin-bottom:15px" *ngIf="(license$ | async).licenceError">
            <i class="fa fa-warning"></i> {{(license$ | async).licenceError}}
        </div>
        <rs-button class="secondary" (hit)="enterLicenece()"><?php _('Enter Licence Code') ?></rs-button>
        
        <div *ngIf="(license$ | async).testperiodMode<2 && (license$ | async).testperiodMode>=0" class="alert info margin-top">
                <p><?php _('This software comes in a free and pro edition. While free edition allows you a lot like remote printing, the pro version offers a lot of more cool features. To get an impression of these features, we offer you a free 14 day trial period where you can use all pro features. No automatic switch and no data is required for the trial. Just start the trial and convince your self.') ?></p>
        <p><?php _('Note: The free trial only works with active internet connection!') ?></p>
<rs-button type="button" class="info" (hit)="startPeriod()">
            <i class="fa fa-check"></i> <?php _('Start Free Trial') ?></rs-button>
        </div>
        
        <div class="centered-grid" style="margin-top:10px">         
            <div  *ngFor="let n of net.ipv4" class="col-2" style="min-width:200px">
                <h2>{{connectionHandler.httpType}}://{{n.ip}}:{{net.port}}</h2>
                <div style="text-align: center;margin:8px">
                    <rs-qrcode [ip]="n.ip" [port]="net.port" margin="2" modSize="5"></rs-qrcode>
                </div>
            </div>
         </div>

    </div>
</div>
<div *ngIf="page==1">
    <h1><?php _('Language') ?></h1>
    <div class="content-h1" rs-drag>
       <div class="iconlist">
           <div class="button-icon sep-icon-always full" *ngFor="let l of languages$ | async">
                <rs-button class="secondary outline full" (hit)="selectLanguage(l)">
                    <i *ngIf="(front$ | async).frontSetting"><rs-radio [on]="l.id" [value]="(front$ | async).frontSetting.language" class="primary"></rs-radio></i> 
                    <h3 class="text single"><img [src]="l.flag"> {{l.name}} {{(front$ | async).language}}</h3>
                </rs-button>
           </div>
        </div>
    </div>
</div>
</main>
</rs-page>

 `,
    changeDetection: ChangeDetectionStrategy.Default
})
class FrontRegister {
    @select(['server', 'languages']) languages$: Observable<Language[]>;
    @select('license') license$: Observable<LicenseState>;
    @select('wifi') wifi$: Observable<WifiState>;
    @select(['server', 'settings']) front$: Observable<any>;
    public page: number = 0;
    online: boolean = window.navigator.onLine;
    net: any = {ipv4: []};
    private connectionSubscription: ISubscription;

    constructor(public server: RepetierServer,
                public modal: RSModal,
                public view: ViewContainerRef,
                public busy: RSUIVisualAids,
                private kbd: RSLicenceKeyboard,
                private licenseAction: LicenseAction,
                private connectionHandler: ConnectionHandler,
                private serverAction: ServerAction,
                private visualAid: VisualAids,
                private redux: NgRedux<RepetierState>) {
        //RSModal.defaultView = view;
        this.connectionSubscription = connectionHandler.connectionState.subscribe(on => {
            if(on)
                this.updateInterfaces();
        });
    }

    private localEventHandler = (evt: ServerEvent) => {
        switch (evt.event) {
            case "connected":
                this.updateInterfaces();
                break;
        }
    };


    startPeriod() {
        this.connectionHandler.send("setTestperiodMode",{mode:2});
    };

    updateInterfaces() {
        this.connectionHandler.networkInterfaces().then((data)=> {
            this.net = data;
        }, ()=> {
        });
    }

    ngOnDestroy() {
        this.connectionSubscription.unsubscribe();
    }

    selectLanguage(l: Language) {
        this.serverAction.updateSetting("frontSetting", Object.assign({}, this.redux.getState().server.settings["frontSetting"], {language: l.id})).then(()=> {
            this.visualAid.showBusy("<?php _('Switching language ...') ?>");
            window.location.assign(window.location.pathname + "?rand=" + Math.random());
        })
    }

    enterLicenece() {
        this.kbd.getString("", '<i class="rs rs-key"></i> ' + "<?php _('License Key') ?>", {}).then(
            (v) => {
                this.licenseAction.activateLicense(v, true);
            }, () => {
            }
        );
    }
}
@Component({
    selector: 'register-app',
    template: `<router-outlet></router-outlet>`
})
export class RegisterApp {
    @select('license') license$: Observable<LicenseState>;
    private licenseSubscription: ISubscription;
    wifi:WifiState = undefined;
    serverState:ServerState = undefined;
    screenTimer:any = undefined;
    screenTimeout:number = -1;
    screenHidden:boolean = false;
    screenEnergySavingInitalized:boolean = false;
    private serverSubscription: ISubscription;
    private wifiSubscription: ISubscription;
    @select('server') server$:Observable<ServerState>;
    @select('wifi') wifi$:Observable<WifiState>;

    constructor(public server: RepetierServer,
                public modal: RSModal,
                public view: ViewContainerRef,
                private connectionHandler: ConnectionHandler,
                private serverAction: ServerAction) {
        RSModal.defaultView = view;
        this.serverAction.initSetting("screensaver",{timeout:10,energySaving:true});
        this.serverSubscription = this.server$.subscribe((s:ServerState) => {
            this.serverState = s;
            if(s.settings && s.settings["screensaver"] && s.settings["screensaver"].timeout != this.screenTimeout) {
                this.screenTimeout = s.settings["screensaver"].timeout;
                this.initEnergySaving();
                this.resetScreensaver();
            }
        });
        this.wifiSubscription = this.wifi$.subscribe((w:WifiState) => {
            this.wifi = w;
            this.initEnergySaving();
        });
        window.document.body.addEventListener("mousemove",this.resetScreensaver);
        document.getElementById("screensaver").addEventListener("click",this.disableScreensaver);
        this.checkLicense();
    }
    ngOnInit() {
        this.connectionHandler.connectFrontend();
    }
    ngOnDestroy() {
        document.getElementById("screensaver").removeEventListener("click",this.disableScreensaver);
        window.document.body.removeEventListener("mousemove",this.resetScreensaver);
        this.wifiSubscription.unsubscribe();
        this.serverSubscription.unsubscribe();
        this.licenseSubscription.unsubscribe();
        this.connectionHandler.close();
        this.server.dispose();
    }


    initEnergySaving() {
        if(this.screenEnergySavingInitalized || !this.wifi || this.screenTimeout<0 || !this.wifi.screensaver)
            return;
        this.screenEnergySavingInitalized = true;
        if(this.screenTimeout == 0 || !this.serverState.settings["screensaver"].energySaving) {
            this.connectionHandler.send("screensaver",{enable:0,timeout:0});
        } else {
            this.connectionHandler.send("screensaver",{enable:1,timeout:this.screenTimeout*60+10});
        }
    }

    triggerScreensaver = () => {
        this.screenTimer = undefined;
        this.screenHidden = true;
        document.getElementById("screensaver").style.display = "block";
    };

    disableScreensaver = (event:MouseEvent) => {
        if(this.screenHidden) {
            this.screenHidden = false;
            document.getElementById("screensaver").style.display = "none";
            this.screenTimer = setTimeout(this.triggerScreensaver,this.screenTimeout*60000);
        }
        event.stopPropagation();
    };

    resetScreensaver = () => {
        if(this.screenHidden ) {
            return;
        }
        if(this.screenTimer)
            window.clearTimeout(this.screenTimer);
        if(this.screenTimeout <= 0)
            return; // disabled
        this.screenTimer = setTimeout(this.triggerScreensaver,this.screenTimeout*60000);
    };

    private checkLicense() {
        this.licenseSubscription = this.license$.subscribe(license => {
            if (!license.dataLoaded)
                return;
            if (license.licensed || license.testperiodMode == 2) {
                // redirect to frontend when we have a license!
                window.location.href = license.printerFrontendUrl;
            }
        });
    }
}

const appRoutes: Routes = [
    {
        path: 'wlan',
        component: WLANComponent
    },
    {
        path: '**',
        component: FrontRegister
    }
];

@NgModule({
    imports: [
        BrowserModule,
        FrontUIModule,
        HttpModule,
        RouterModule.forRoot(appRoutes)
    ],
    declarations: [FrontRegister, RegisterApp, WLANComponent],
    bootstrap: [RegisterApp],
    providers: [
        RepetierServer,
        {provide: VisualAids, useClass: RSUIVisualAids}
    ]
})
export class AppModule {
}

// uncomment for maximum speed during production
enableProdMode();


// Compile and launch the module
platformBrowserDynamic().bootstrapModule(AppModule);

==> Repetier-Server-Frontend-0.90.1.zip: Repetier-Server-Frontend/wwwsrc/modules/front2/app/register.browser.ts <==
/* (C) 2016 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {platformBrowserDynamic} from '@angular/platform-browser-dynamic';
import {Component, ViewContainerRef, ChangeDetectionStrategy} from '@angular/core';
import {Routes, RouterModule} from '@angular/router';
import {BrowserModule} from '@angular/platform-browser';
import {enableProdMode} from '@angular/core';
import {HttpModule} from '@angular/http';
import {
    RepetierServer, Language, WifiState, LicenseState, LicenseAction, ConnectionHandler,
    ServerAction, RepetierState, VisualAids, ServerEvent, ServerState
} from "@repetier/binding";
import {FrontUIModule, RSModal, RSUIVisualAids, RSLicenceKeyboard} from '@repetier/front-ui';
import {ISubscription} from "rxjs/Subscription";
import {NgModule} from '@angular/core';
import {WLANComponent} from "./wlan.component";
import {select, NgRedux} from 'ng2-redux';
import {Observable} from 'rxjs/Observable';
import {ExternalCommand, PrintersState} from "@repetier/binding/index";

@Component({
    selector: 'front-register',
    template: `
<rs-page>
<side>
    <rs-sideicon title="<?php _('Home') ?>" icon="rs rs-key" (rsclick)="page=0"></rs-sideicon>
</side>
<side>
    <rs-sideicon *ngIf="(wifi$ | async).manageable" icon="fa fa-wifi" title="WLAN" link="/wlan"></rs-sideicon>
</side>
<side>
    <rs-sideicon title="<?php _('Language') ?>" icon="fa fa-language" (rsclick)="page=1"></rs-sideicon>
</side>
<main>
<div *ngIf="page==0">
    <h1 class="margin-bottom"><i class="rs rs-key"></i> <?php _('License Activation') ?></h1>
    <div class="content-h1 margin" rs-drag>
        <div *ngIf="!online" class="alert warning">
            <i class="fa fa-warning"></i> <?php _('It seems you are not connected with the internet. Activation will work only with active internet connection!') ?>
        </div>
        <p> <?php _('The requested function requires a active licence.') ?></p>
        <div class="alert error" style="margin-bottom:15px" *ngIf="(license$ | async).licenceError">
            <i class="fa fa-warning"></i> {{(license$ | async).licenceError}}
        </div>
        <rs-button class="secondary" (hit)="enterLicenece()"><?php _('Enter Licence Code') ?></rs-button>
        
        <div *ngIf="(license$ | async).testperiodMode<2 && (license$ | async).testperiodMode>=0" class="alert info margin-top">
                <p><?php _('This software comes in a free and pro edition. While free edition allows you a lot like remote printing, the pro version offers a lot of more cool features. To get an impression of these features, we offer you a free 14 day trial period where you can use all pro features. No automatic switch and no data is required for the trial. Just start the trial and convince your self.') ?></p>
        <p><?php _('Note: The free trial only works with active internet connection!') ?></p>
<rs-button type="button" class="info" (hit)="startPeriod()">
            <i class="fa fa-check"></i> <?php _('Start Free Trial') ?></rs-button>
        </div>
        
        <div class="centered-grid" style="margin-top:10px">         
            <div  *ngFor="let n of net.ipv4" class="col-2" style="min-width:200px">
                <h2>{{connectionHandler.httpType}}://{{n.ip}}:{{net.port}}</h2>
                <div style="text-align: center;margin:8px">
                    <p>MAC: {{n.mac}}</p>
                    <rs-qrcode [ip]="n.ip" [port]="net.port" margin="2" modSize="5"></rs-qrcode>
                </div>
            </div>
         </div>
    <div class="iconlist">
        <div class="button-icon sep-icon" *ngFor="let f of filtered(commands$ | async)" style="min-width:12em">
            <rs-button class="secondary outline full" (hit)="runCommand(f)">
            <i class="fa fa-play"></i>
            <h3 class="text" style="padding:8px">{{f.name}}</h3></rs-button>
        </div> 
    </div>

    </div>

</div>
<div *ngIf="page==1">
    <h1><?php _('Language') ?></h1>
    <div class="content-h1" rs-drag>
       <div class="iconlist">
           <div class="button-icon sep-icon-always full" *ngFor="let l of languages$ | async">
                <rs-button class="secondary outline full" (hit)="selectLanguage(l)">
                    <i *ngIf="(front$ | async).frontSetting"><rs-radio [on]="l.id" [value]="(front$ | async).frontSetting.language" class="primary"></rs-radio></i> 
                    <h3 class="text single"><img [src]="l.flag"> {{l.name}} {{(front$ | async).language}}</h3>
                </rs-button>
           </div>
        </div>
    </div>
</div>
</main>
</rs-page>

 `,
    changeDetection: ChangeDetectionStrategy.Default
})
class FrontRegister {
    @select(['server', 'languages']) languages$: Observable<Language[]>;
    @select('license') license$: Observable<LicenseState>;
    @select('wifi') wifi$: Observable<WifiState>;
    @select(['server', 'settings']) front$: Observable<any>;
    @select(['server', 'externalCommands']) commands$: Observable<ExternalCommand[]>;
    @select('printers') printers$: Observable<PrintersState>;
    private printersSubscription: ISubscription;
    active: string = '';

    public page: number = 0;
    online: boolean = window.navigator.onLine;
    net: any = {ipv4: []};
    private connectionSubscription: ISubscription;

    constructor(public server: RepetierServer,
                public modal: RSModal,
                public view: ViewContainerRef,
                public busy: RSUIVisualAids,
                private kbd: RSLicenceKeyboard,
                private licenseAction: LicenseAction,
                private connectionHandler: ConnectionHandler,
                private serverAction: ServerAction,
                private visualAid: VisualAids,
                private redux: NgRedux<RepetierState>) {
        //RSModal.defaultView = view;
        this.connectionSubscription = connectionHandler.connectionState.subscribe(on => {
            if (on)
                this.updateInterfaces();
        });
        this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
            this.active = p.active;
        });
    }

    private localEventHandler = (evt: ServerEvent) => {
        switch (evt.event) {
            case "connected":
                this.updateInterfaces();
                break;
        }
    };


    startPeriod() {
        this.connectionHandler.send("setTestperiodMode", {mode: 2});
    };

    updateInterfaces() {
        this.connectionHandler.networkInterfaces().then((data) => {
            this.net = data;
        }, () => {
        });
    }

    ngOnDestroy() {
        this.connectionSubscription.unsubscribe();
        this.printersSubscription.unsubscribe();
    }

    selectLanguage(l: Language) {
        this.serverAction.updateSetting("frontSetting", Object.assign({}, this.redux.getState().server.settings["frontSetting"], {language: l.id})).then(() => {
            this.visualAid.showBusy("<?php _('Switching language ...') ?>");
            window.location.assign(window.location.pathname + "?rand=" + Math.random());
        })
    }

    enterLicenece() {
        this.kbd.getString("", '<i class="rs rs-key"></i> ' + "<?php _('License Key') ?>", {}).then(
            (v) => {
                this.licenseAction.activateLicense(v, true);
            }, () => {
            }
        );
    }

    filtered(list) {
        let l = []
        for (let x of list) {
            if (x.local && (x.slug === '' || x.slug === this.active))
                l.push(x)
        }
        return l
    }

    runCommand(cmd: ExternalCommand) {
        if (cmd.confirm) {
            this.modal.confirm("<?php _('Security Question') ?>", cmd.confirm, {}).then(
                (res) => this.serverAction.runExternalCommand(cmd), () => {
                }
            )
        } else {
            this.serverAction.runExternalCommand(cmd);
        }
    }
}

@Component({
    selector: 'register-app',
    template: `<router-outlet></router-outlet>`
})
export class RegisterApp {
    @select('license') license$: Observable<LicenseState>;
    private licenseSubscription: ISubscription;
    wifi: WifiState = undefined;
    serverState: ServerState = undefined;
    screenTimer: any = undefined;
    screenTimeout: number = -1;
    screenHidden: boolean = false;
    screenEnergySavingInitalized: boolean = false;
    private serverSubscription: ISubscription;
    private wifiSubscription: ISubscription;
    @select('server') server$: Observable<ServerState>;
    @select('wifi') wifi$: Observable<WifiState>;

    constructor(public server: RepetierServer,
                public modal: RSModal,
                public view: ViewContainerRef,
                private connectionHandler: ConnectionHandler,
                private serverAction: ServerAction) {
        RSModal.defaultView = view;
        this.serverAction.initSetting("screensaver", {timeout: 10, energySaving: true});
        this.serverSubscription = this.server$.subscribe((s: ServerState) => {
            this.serverState = s;
            if (s.settings && s.settings["screensaver"] && s.settings["screensaver"].timeout != this.screenTimeout) {
                this.screenTimeout = s.settings["screensaver"].timeout;
                this.initEnergySaving();
                this.resetScreensaver();
            }
        });
        this.wifiSubscription = this.wifi$.subscribe((w: WifiState) => {
            this.wifi = w;
            this.initEnergySaving();
        });
        window.document.body.addEventListener("mousemove", this.resetScreensaver);
        document.getElementById("screensaver").addEventListener("click", this.disableScreensaver);
        this.checkLicense();
    }

    ngOnInit() {
        this.connectionHandler.connectFrontend();
    }

    ngOnDestroy() {
        document.getElementById("screensaver").removeEventListener("click", this.disableScreensaver);
        window.document.body.removeEventListener("mousemove", this.resetScreensaver);
        this.wifiSubscription.unsubscribe();
        this.serverSubscription.unsubscribe();
        this.licenseSubscription.unsubscribe();
        this.connectionHandler.close();
        this.server.dispose();
    }


    initEnergySaving() {
        if (this.screenEnergySavingInitalized || !this.wifi || this.screenTimeout < 0 || !this.wifi.screensaver)
            return;
        this.screenEnergySavingInitalized = true;
        if (this.screenTimeout == 0 || !this.serverState.settings["screensaver"].energySaving) {
            this.connectionHandler.send("screensaver", {enable: 0, timeout: 0});
        } else {
            this.connectionHandler.send("screensaver", {enable: 1, timeout: this.screenTimeout * 60 + 10});
        }
    }

    triggerScreensaver = () => {
        this.screenTimer = undefined;
        this.screenHidden = true;
        document.getElementById("screensaver").style.display = "block";
    };

    disableScreensaver = (event: MouseEvent) => {
        if (this.screenHidden) {
            this.screenHidden = false;
            document.getElementById("screensaver").style.display = "none";
            this.screenTimer = setTimeout(this.triggerScreensaver, this.screenTimeout * 60000);
        }
        event.stopPropagation();
    };

    resetScreensaver = () => {
        if (this.screenHidden) {
            return;
        }
        if (this.screenTimer)
            window.clearTimeout(this.screenTimer);
        if (this.screenTimeout <= 0)
            return; // disabled
        this.screenTimer = setTimeout(this.triggerScreensaver, this.screenTimeout * 60000);
    };

    private checkLicense() {
        this.licenseSubscription = this.license$.subscribe(license => {
            if (!license.dataLoaded)
                return;
            if (license.licensed || license.testperiodMode == 2) {
                // redirect to frontend when we have a license!
                window.location.href = license.printerFrontendUrl;
            }
        });
    }
}

const appRoutes: Routes = [
    {
        path: 'wlan',
        component: WLANComponent
    },
    {
        path: '**',
        component: FrontRegister
    }
];

@NgModule({
    imports: [
        BrowserModule,
        FrontUIModule,
        HttpModule,
        RouterModule.forRoot(appRoutes)
    ],
    declarations: [FrontRegister, RegisterApp, WLANComponent],
    bootstrap: [RegisterApp],
    providers: [
        RepetierServer,
        {provide: VisualAids, useClass: RSUIVisualAids}
    ]
})
export class AppModule {
}

// uncomment for maximum speed during production
enableProdMode();


// Compile and launch the module
platformBrowserDynamic().bootstrapModule(AppModule);
